==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/Compute/AmazonEc2C5AdInstance.md <==
# AmazonEc2C5AdInstance


```text
aws-q3-2021/Resource/Compute/AmazonEc2C5AdInstance
```

```text
include('aws-q3-2021/Resource/Compute/AmazonEc2C5AdInstance')
```



| Illustration | AmazonEc2C5AdInstance | AmazonEc2C5AdInstanceCard | AmazonEc2C5AdInstanceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Compute/AmazonEc2C5AdInstance.png) | ![illustration for AmazonEc2C5AdInstance](../../../aws-q3-2021/Resource/Compute/AmazonEc2C5AdInstance.Local.png) | ![illustration for AmazonEc2C5AdInstanceCard](../../../aws-q3-2021/Resource/Compute/AmazonEc2C5AdInstanceCard.Local.png) | ![illustration for AmazonEc2C5AdInstanceGroup](../../../aws-q3-2021/Resource/Compute/AmazonEc2C5AdInstanceGroup.Local.png) |




## AmazonEc2C5AdInstance

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2C5AdInstance
include('aws-q3-2021/Resource/Compute/AmazonEc2C5AdInstance')

' renders the element
AmazonEc2C5AdInstance('AmazonEc2C5AdInstance', 'Amazon Ec2 C5 Ad Instance', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2C5AdInstance
include('aws-q3-2021/Resource/Compute/AmazonEc2C5AdInstance')

' renders the element
AmazonEc2C5AdInstance('AmazonEc2C5AdInstance', 'Amazon Ec2 C5 Ad Instance', 'an optional tech label')
@enduml
```

## AmazonEc2C5AdInstanceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2C5AdInstanceCard
include('aws-q3-2021/Resource/Compute/AmazonEc2C5AdInstance')

' renders the element
AmazonEc2C5AdInstanceCard('AmazonEc2C5AdInstanceCard', 'Amazon Ec2 C5 Ad Instance Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2C5AdInstanceCard
include('aws-q3-2021/Resource/Compute/AmazonEc2C5AdInstance')

' renders the element
AmazonEc2C5AdInstanceCard('AmazonEc2C5AdInstanceCard', 'Amazon Ec2 C5 Ad Instance Card', 'an optional description')
@enduml
```

## AmazonEc2C5AdInstanceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2C5AdInstanceGroup
include('aws-q3-2021/Resource/Compute/AmazonEc2C5AdInstance')

' renders the element
AmazonEc2C5AdInstanceGroup('AmazonEc2C5AdInstanceGroup', 'Amazon Ec2 C5 Ad Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2C5AdInstanceGroup
include('aws-q3-2021/Resource/Compute/AmazonEc2C5AdInstance')

' renders the element
AmazonEc2C5AdInstanceGroup('AmazonEc2C5AdInstanceGroup', 'Amazon Ec2 C5 Ad Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-q3-2021/Resource/Compute/AmazonEc2C5AdInstance.md <==
# AmazonEc2C5AdInstance


```text
aws-q3-2021/Resource/Compute/AmazonEc2C5AdInstance
```

```text
include('aws-q3-2021/Resource/Compute/AmazonEc2C5AdInstance')
```



| Illustration | AmazonEc2C5AdInstance | AmazonEc2C5AdInstanceCard | AmazonEc2C5AdInstanceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Compute/AmazonEc2C5AdInstance.png) | ![illustration for AmazonEc2C5AdInstance](../../../aws-q3-2021/Resource/Compute/AmazonEc2C5AdInstance.Local.png) | ![illustration for AmazonEc2C5AdInstanceCard](../../../aws-q3-2021/Resource/Compute/AmazonEc2C5AdInstanceCard.Local.png) | ![illustration for AmazonEc2C5AdInstanceGroup](../../../aws-q3-2021/Resource/Compute/AmazonEc2C5AdInstanceGroup.Local.png) |




## AmazonEc2C5AdInstance

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2C5AdInstance
include('aws-q3-2021/Resource/Compute/AmazonEc2C5AdInstance')

' renders the element
AmazonEc2C5AdInstance('AmazonEc2C5AdInstance', 'Amazon Ec2 C5 Ad Instance', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2C5AdInstance
include('aws-q3-2021/Resource/Compute/AmazonEc2C5AdInstance')

' renders the element
AmazonEc2C5AdInstance('AmazonEc2C5AdInstance', 'Amazon Ec2 C5 Ad Instance', 'an optional tech label')
@enduml
```

## AmazonEc2C5AdInstanceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2C5AdInstanceCard
include('aws-q3-2021/Resource/Compute/AmazonEc2C5AdInstance')

' renders the element
AmazonEc2C5AdInstanceCard('AmazonEc2C5AdInstanceCard', 'Amazon Ec2 C5 Ad Instance Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2C5AdInstanceCard
include('aws-q3-2021/Resource/Compute/AmazonEc2C5AdInstance')

' renders the element
AmazonEc2C5AdInstanceCard('AmazonEc2C5AdInstanceCard', 'Amazon Ec2 C5 Ad Instance Card', 'an optional description')
@enduml
```

## AmazonEc2C5AdInstanceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2C5AdInstanceGroup
include('aws-q3-2021/Resource/Compute/AmazonEc2C5AdInstance')

' renders the element
AmazonEc2C5AdInstanceGroup('AmazonEc2C5AdInstanceGroup', 'Amazon Ec2 C5 Ad Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonEc2C5AdInstanceGroup
include('aws-q3-2021/Resource/Compute/AmazonEc2C5AdInstance')

' renders the element
AmazonEc2C5AdInstanceGroup('AmazonEc2C5AdInstanceGroup', 'Amazon Ec2 C5 Ad Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
